@@ -1,6 +1,6 @@
 from django.dispatch import receiver
 
-from ephios.event_management.signup import register_signup_methods
+from ephios.core.signup import register_signup_methods
 from ephios.plugins.basesignup.signup.instant import InstantConfirmationSignupMethod
 from ephios.plugins.basesignup.signup.request_confirm import RequestConfirmSignupMethod
 from ephios.plugins.basesignup.signup.section_based import SectionBasedSignupMethod
